<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// hindi.php
//
// Hindi language strings
// हिंदी शब्द
// Translator: Aniruddha Thombre <imagineers7@yahoo.com>
// अनुवादक: अनिरुद्ध ठोंबरे

$lang["LANGUAGETAG"] = "hin"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Hindi";
$lang["LANGUAGENAMENATIVE"] = "हिंदी";
$lang["LANGUAGENAMEHTML"] = "&#2361;&#2367;&#2306;&#2342;&#2368;";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "टिप्पणी";
$lang["DIFF"] = "फ़र्क";

$lang["NOREP"] = "आवृत्तिकोष नही दिया गया है";
$lang["NOPATH"] = "पथ नही मिला";
$lang["NOACCESS"] = "आपके पास यह जानकारी देखने के अधिकार नही है";
$lang["RESTRICTED"] = "मर्यादित अधिकार";
$lang["SUPPLYREP"] = "कृपया, include/config.php इस लेख्यपत्र में \$config->parentPath या \$config->addRepository इस्तेमाल करके आवृत्तिकोष का पथ संस्थापित करें.<p>अधिक जानकारी के लिए प्रस्थापक पुस्तिका पढ़ें";

$lang["DIFFREVS"] = "आवृत्तियोंमें हुए बदल";
$lang["AND"] = "और";
$lang["REV"] = "आवृत्ती";
$lang["LINE"] = "पंक्ति";
$lang["LINENO"] = "पंक्ति क्र.";
$lang["SHOWENTIREFILE"] = "संपूर्ण लेख्यपत्र देखिए";
$lang["SHOWCOMPACT"] = "सिर्फ़ बदले हुए हिस्से देखें";
$lang["IGNOREWHITESPACE"] = "रिक्त स्थान छोड़ दें";
$lang["REGARDWHITESPACE"] = "रिक्त स्थानभी देखें";

$lang["LISTING"] = "सूची";
$lang["FILEDETAIL"] = "अधिक जानकारी";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "पुरानी आवृत्तिके साथ तुलना करें";
$lang["BLAME"] = "ज़िम्मेदार";
$lang["BLAMEFOR"] = "आवृत्तिके बारे में ज़िम्मेदारी की जानकारी";

$lang["REVINFO"] = "आवृत्ति की जानकारी";
$lang["GOYOUNGEST"] = "सबसे नयी आवृत्तिक़ी ओर चलें";
$lang["LASTMOD"] = "अंतिम बदल";
$lang["LOGMSG"] = "टिप्पणी";
$lang["CHANGES"] = "बदल";
$lang["SHOWCHANGED"] = "बदले हुए लेख्यपत्र देखें";
$lang["HIDECHANGED"] = "बदले हुए लेख्यपत्र छुपायें";
$lang["NEWFILES"] = "नये लेख्यपत्र";
$lang["CHANGEDFILES"] = "बदले हुए लेख्यपत्र";
$lang["DELETEDFILES"] = "मिटाए हुए लेख्यपत्र";
$lang["VIEWLOG"] = "टिप्पणीयाँ";
$lang["PATH"] = "पथ";
$lang["AUTHOR"] = "लेखक";
$lang["AGE"] = "आयु";
$lang["CURDIR"] = "सद्यसुचि";
//$lang["TARBALL"] = "Tarball";
//$lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "पीछे";
$lang["NEXT"] = "आगे";
$lang["SHOWALL"] = "सभी";

$lang["BADCMD"] = "यह आदेश चल नही सकता";
$lang["UNKNOWNREVISION"] = "यह आवृत्ती नही मिल सकी";

$lang["POWERED"] = "<a href=\"https://websvnphp.github.io/\">WebSVN</a> से संचालीत";
$lang["PROJECTS"] = "Subversion आवृत्तीकोष";
$lang["SERVER"] = "Subversion संगणक";

$lang["FILTER"] = "छानने के निकष";
$lang["STARTLOG"] = "आवृत्ती से";
$lang["ENDLOG"] = "आवृत्ती तक";
$lang["MAXLOG"] = "अधिकतम आवृत्तीयाँ";
$lang["SEARCHLOG"] = "ढूंढीए:";
$lang["CLEARLOG"] = "अभीके निकष निकालिए";
$lang["MORERESULTS"] = "और टिपण्णीयाँ देखिए...";
$lang["NORESULTS"] = "ऐसी टिपण्णीयाँ उपलब्ध नही हैं";
$lang["NOMORERESULTS"] = "आपके शोध मे और टिपण्णीयाँ नही हैं";
$lang["NOPREVREV"] = "इससे पहली आवृत्ती नही हैं";

$lang["RSSFEEDTITLE"] = "WebSVN स. स. स. आगत्";
$lang["FILESMODIFIED"] = "बदले हुए लेख्यपत्र";
$lang["RSSFEED"] = " स. स. स. आगत्";

$lang["DAYLETTER"] = "दि.";
$lang["HOURLETTER"] = "घं.";
$lang["MINUTELETTER"] = "मी.";
$lang["SECONDLETTER"] = "प.";

$lang["GO"] = "जाओ";

$lang["PATHCOMPARISON"] = "पथ तुलना";
$lang["COMPAREPATHS"] = "पथ तुलना";
$lang["COMPAREREVS"] = "आवृत्तियोंमें तुलना";
$lang["PROPCHANGES"] = "गुणोंमे बदल:";
$lang["CONVFROM"] = "यह तुलना पथ बदलने के लिए आवश्यक फ़र्क दिखाती हैं";
$lang["TO"] = "की ओर";
$lang["REVCOMP"] = "उलट तुलना";
$lang["COMPPATH"] = "पथ तुलना:";
$lang["WITHPATH"] = "इस पथ से:";
$lang["FILEDELETED"] = "मिटाया हुआ लेख्यपत्र";
$lang["FILEADDED"] = "नया लेख्यपत्र";

$lang['SEARCH'] = "खोज";
$lang['SEARCH_PLACEHOLDER'] = "यहां आइटम खोजें";
$lang['NOITEMSFOUND'] = "कुछ नहीं मिला";
