<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// italian.php
//
// Italian language strings
// Translated by Andrea Visinoni (andrea.visinoni@gmail.com)

$lang["LANGUAGETAG"] = "it"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Italian";
$lang["LANGUAGENAMENATIVE"] = "Italiano";
$lang["LANGUAGENAMEHTML"] = "Italiano";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "Nessun repository specificato";
$lang["NOPATH"] = "Percorso non trovato";
$lang["NOACCESS"] = "Non hai i permessi necessari per leggere questa directory";
$lang["RESTRICTED"] = "Accesso limitato";
$lang["SUPPLYREP"] = "Configurare un percorso ai repository in include/config.inc usando \$config->parentPath o \$config->addRepository<p>Per maggiori dettagli consultare la guida d'installazione";

$lang["DIFFREVS"] = "Differenze tra le revisioni";
$lang["AND"] = "e";
$lang["REV"] = "Revisione";
$lang["LINE"] = "Linea";
$lang["LINENO"] = "Linea Num.";
$lang["SHOWENTIREFILE"] = "Mostra tutto il file";
$lang["SHOWCOMPACT"] = "Mostra solo aree con differenze";
$lang["IGNOREWHITESPACE"] = "Ignora gli spazi vuoti";
$lang["REGARDWHITESPACE"] = "Rispetta gli spazi vuoti";

$lang["LISTING"] = "Lista directory";
$lang["FILEDETAIL"] = "Dettagli";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Confronta con la precedente";
$lang["BLAME"] = "Responsabilità";
$lang["BLAMEFOR"] = "Informazioni sui responsabili della revisione";

$lang["REVINFO"] = "Informazioni sulla revisione";
$lang["GOYOUNGEST"] = "Vai alla revisione più recente";
$lang["LASTMOD"] = "Ultima modifica";
$lang["LOGMSG"] = "Messaggio di log";
$lang["CHANGES"] = "Cambiamenti";
$lang["SHOWCHANGED"] = "Mostra file modificati";
$lang["HIDECHANGED"] = "Nascondi file modificati";
$lang["NEWFILES"] = "Nuovi File";
$lang["CHANGEDFILES"] = "File modificati";
$lang["DELETEDFILES"] = "File cancellati";
$lang["VIEWLOG"] = "Visualizza Log";
$lang["PATH"] = "Percorso";
$lang["AUTHOR"] = "Autore";
$lang["AGE"] = "Anzianità";
$lang["CURDIR"] = "Directory corrente";
$lang["TARBALL"] = "Archivio";
$lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Precedente";
$lang["NEXT"] = "Successivo";
$lang["SHOWALL"] = "Mostra tutti";

$lang["BADCMD"] = "Errore durante l'esecuzione del comando";
$lang["UNKNOWNREVISION"] = "Revisione non trovata";

// $lang["POWERED"] = "Powered by <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
// $lang["PROJECTS"] = "Repository Subversion";
// $lang["SERVER"] = "Subversion Server";

$lang["FILTER"] = "Opzioni Filtro";
$lang["STARTLOG"] = "Dalla  revisione";
$lang["ENDLOG"] = "Alla revisione";
$lang["MAXLOG"] = "Massime revisioni";
$lang["SEARCHLOG"] = "Cerca";
$lang["CLEARLOG"] = "Pulisci il fitro corrente";
$lang["MORERESULTS"] = "Trova più risultati...";
$lang["NORESULTS"] = "Non ci sono log che soddifano la tua ricerca";
$lang["NOMORERESULTS"] = "Non ci sono più log che soddifano la tua ricerca";
$lang["NOPREVREV"] = "Nessuna revisione precedente";

$lang["RSSFEEDTITLE"] = "WebSVN feed RSS";
$lang["FILESMODIFIED"] = "file modificati";
$lang["RSSFEED"] = "feed RSS";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Vai";

$lang["PATHCOMPARISON"] = "Confronto percorso";
$lang["COMPAREPATHS"] = "Confronta percorsi";
$lang["COMPAREREVS"] = "Confronta Revisioni";
$lang["PROPCHANGES"] = "Modifica delle proprietà:";
$lang["CONVFROM"] = "Questo confronto mostra i cambiamenti necessari per convertire il percorso ";
$lang["TO"] = "A";
$lang["REVCOMP"] = "Confronto inverso";
$lang["COMPPATH"] = "Confronta percorso:";
$lang["WITHPATH"] = "Con il percorso:";
$lang["FILEDELETED"] = "File cancellato";
$lang["FILEADDED"] = "Nuovo file";

$lang['SEARCH'] = "Ricerca";
$lang['SEARCH_PLACEHOLDER'] = "Cerca qui gli articoli";
$lang['NOITEMSFOUND'] = "Nessun articolo trovato";
