<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// russian.php
//
// Russian language strings (UTF-8 encoding)
// by Alexey Chumakov <alex@chumakov.ru>

$lang["LANGUAGETAG"] = "ru"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Russian";
$lang["LANGUAGENAMENATIVE"] = "Русский";
$lang["LANGUAGENAMEHTML"] = "&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "Журнал";
$lang["DIFF"] = "Различия";

$lang["NOREP"] = "Не задано хранилище";
$lang["NOPATH"] = "Путь не найден";
$lang["NOACCESS"] = "Для чтения этого каталога у вас нет нужных прав";
$lang["RESTRICTED"] = "Ограниченный доступ";
$lang["SUPPLYREP"] = "Пожалуйста, настройте путь к хранилищу в include/config.php, пользуясь \$config->parentPath или \$config->addRepository<p>Дополнительные сведения приведены в руководстве по установке ";

$lang["DIFFREVS"] = "Различия между редакциями";
$lang["AND"] = "и";
$lang["REV"] = "Редакция";
$lang["LINE"] = "Строка";
$lang["LINENO"] = "№ строки";
$lang["SHOWENTIREFILE"] = "Весь файл";
$lang["SHOWCOMPACT"] = "Только различия";
$lang["IGNOREWHITESPACE"] = "Не учитывать пробелы";
$lang["REGARDWHITESPACE"] = "Учитывать пробелы";

$lang["LISTING"] = "Список файлов";
$lang["FILEDETAIL"] = "Содержимое файла";
$lang["VIEWAS"] = "Просмотреть как";
$lang["DIFFPREV"] = "Сравнить с предыдущей";
$lang["BLAME"] = "Авторство";
$lang["BLAMEFOR"] = "Сведения об авторстве для редакции ";

$lang["REVINFO"] = "Сведения о редакции";
$lang["GOYOUNGEST"] = "К новейшей редакции";
$lang["LASTMOD"] = "Последнее изменение";
$lang["LOGMSG"] = "Запись в журнале";
$lang["CHANGES"] = "Изменения";
$lang["SHOWCHANGED"] = "Показать измененные файлы";
$lang["HIDECHANGED"] = "Скрыть измененные файлы";
$lang["NEWFILES"] = "Новые файлы";
$lang["CHANGEDFILES"] = "Измененные файлы";
$lang["DELETEDFILES"] = "Удаленные файлы";
$lang["VIEWLOG"] = "Открыть журнал";
$lang["PATH"] = "Путь";
$lang["AUTHOR"] = "Автор";
$lang["AGE"] = "Давность";
$lang["CURDIR"] = "Текущий каталог";
$lang["TARBALL"] = "Архив";
$lang["DOWNLOAD"] = "Скачать";

$lang["PREV"] = "пред.";
$lang["NEXT"] = "след.";
$lang["SHOWALL"] = "показать все";

$lang["BADCMD"] = "Ошибка при выполнении команды";
$lang["UNKNOWNREVISION"] = "Редакция не найдена";

$lang["POWERED"] = "Работает на <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Хранилища Subversion";
$lang["SERVER"] = "Сервер Subversion";

$lang["FILTER"] = "Параметры фильтрации";
$lang["STARTLOG"] = "От редакции";
$lang["ENDLOG"] = "До редакции";
$lang["MAXLOG"] = "Макс. редакций";
$lang["SEARCHLOG"] = "искать";
$lang["CLEARLOG"] = "очистить текущий фильтр";
$lang["MORERESULTS"] = "найти еще совпадения...";
$lang["NORESULTS"] = "Нет записей, совпадающих с вашим запросом";
$lang["NOMORERESULTS"] = "Больше нет записей, совпадающих с вашим запросом";
$lang["NOPREVREV"] = "Нет более ранней редакции";

$lang["RSSFEEDTITLE"] = "RSS-канал WebSVN";
$lang["FILESMODIFIED"] = "файл(ов) изменено";
$lang["RSSFEED"] = "RSS";

$lang["DAYLETTER"] = "д";
$lang["HOURLETTER"] = "ч";
$lang["MINUTELETTER"] = "м";
$lang["SECONDLETTER"] = "с";

$lang["GO"] = "Перейти";

$lang["PATHCOMPARISON"] = "Сравнение путей";
$lang["COMPAREPATHS"] = "Сравнить пути";
$lang["COMPAREREVS"] = "Сравнить редакции";
$lang["PROPCHANGES"] = "Изменения свойств:";
$lang["CONVFROM"] = "Такое сравнение показывает изменения, нужные для для преобразования пути ";
$lang["TO"] = "В";
$lang["REVCOMP"] = "Обратное сравнение";
$lang["COMPPATH"] = "Сравнить путь:";
$lang["WITHPATH"] = "С путем:";
$lang["FILEDELETED"] = "Файл удален";
$lang["FILEADDED"] = "Новый файл";

$lang['SEARCH'] = "Поиск";
$lang['SEARCH_PLACEHOLDER'] = "Искать предметы здесь";
$lang['NOITEMSFOUND'] = "Ничего не найдено";
