<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// slovak.php
//
// Slovak language strings (UTF-8 encoding)

$lang["LANGUAGETAG"] = "sk"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Slovak";
$lang["LANGUAGENAMENATIVE"] = "Slovenčina";
$lang["LANGUAGENAMEHTML"] = "Sloven&#269;ina";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "Denník";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "Neurčené úložisko";
$lang["NOPATH"] = "Cesta nebola nájdená";
$lang["NOACCESS"] = "Nemáte oprávnenie pre čítanie tohto adresára";
$lang["RESTRICTED"] = "Obmedzený prístup";
$lang["SUPPLYREP"] = "Prosím nastavte cestu k úložisku v include/config.php pomocou \$config->parentPath alebo \$config->addRepository<p>Pre ďalšie detaily konzultujte inštalačnú príručku";

$lang["DIFFREVS"] = "Rozdiel medzi revíziami";
$lang["AND"] = "a";
$lang["REV"] = "Rev";
$lang["LINE"] = "Riadok";
$lang["LINENO"] = "Riadok č.";
$lang["SHOWENTIREFILE"] = "Ukáž celý súbor";
$lang["SHOWCOMPACT"] = "Ukáž len oblasti s rozdielmi";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
$lang["FILEDETAIL"] = "Podrobnosti";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Porovnaj s predchádzajúcou";
$lang["BLAME"] = "Blame";
$lang["BLAMEFOR"] = "Blame informácie pre rev.";

$lang["REVINFO"] = "Informácie o revízii";
$lang["GOYOUNGEST"] = "Choď na aktuálnu revíziu";
$lang["LASTMOD"] = "Posledná modifikácia";
$lang["LOGMSG"] = "Správa denníka";
$lang["CHANGES"] = "Zmeny";
$lang["SHOWCHANGED"] = "Ukáž zmenené súbory";
$lang["HIDECHANGED"] = "Skry smenené súbory";
$lang["NEWFILES"] = "Nové súbory";
$lang["CHANGEDFILES"] = "Zmenené súbory";
$lang["DELETEDFILES"] = "Odstránené súbory";
$lang["VIEWLOG"] = "Zobraz denník";
$lang["PATH"] = "Cesta";
$lang["AUTHOR"] = "Autor";
$lang["AGE"] = "Vek";
$lang["CURDIR"] = "Aktuálny priečinok";
$lang["TARBALL"] = "Tarball";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Predch";
$lang["NEXT"] = "Ďalší";
$lang["SHOWALL"] = "Ukáž všetko";

$lang["BADCMD"] = "Chyba pri vykonávaní tohto príkazu";
$lang["UNKNOWNREVISION"] = "Revízia nebola nájdená";

// $lang["POWERED"] = "Powered by <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion úložiská";
$lang["SERVER"] = "Subversion Server";

$lang["FILTER"] = "Možnosti filtrovania";
$lang["STARTLOG"] = "Od rev.";
$lang["ENDLOG"] = "Po rev.";
$lang["MAXLOG"] = "Max. rev.";
$lang["SEARCHLOG"] = "Hľadaj";
$lang["CLEARLOG"] = "Zmaž aktuálny filter";
$lang["MORERESULTS"] = "Nájdi viac zhôd...";
$lang["NORESULTS"] = "Vašej otázke nezodpovedajú žiadne záznamy denníka";
$lang["NOMORERESULTS"] = "Vašej otázke zodpovedá viac záznamov denníka";
$lang["NOPREVREV"] = "Žiadna predchádzajúca revízia";

// $lang["RSSFEEDTITLE"] = "WebSVN RSS feed";
$lang["FILESMODIFIED"] = "súbor(y) zmenený(/é)";
// $lang["RSSFEED"] = "RSS feed";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Choď";

$lang["PATHCOMPARISON"] = "Porovnanie ciest";
$lang["COMPAREPATHS"] = "Porovnaj cesty";
$lang["COMPAREREVS"] = "Porovnaj revízie";
$lang["PROPCHANGES"] = "Zmeny vlastností:";
$lang["CONVFROM"] = "Toto porovnanie ukazuje zmeny potrebné na zmenu cesty ";
$lang["TO"] = "NA";
$lang["REVCOMP"] = "Obrátené porovnanie";
$lang["COMPPATH"] = "Porovnaj cestu:";
$lang["WITHPATH"] = "S cestou:";
$lang["FILEDELETED"] = "Súbor odstránený";
$lang["FILEADDED"] = "Nový súbor";

$lang['SEARCH'] = "Vyhľadávanie";
$lang['SEARCH_PLACEHOLDER'] = "Vyhľadajte položky tu";
$lang['NOITEMSFOUND'] = "Nenašli sa žiadne položky";
