<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// turkish.php
//
// Turkish language strings (UTF-8 encoding)
// by Barış Metin <baris@uludag.org.tr>

$lang["LANGUAGETAG"] = "tr"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Turkish";
$lang["LANGUAGENAMENATIVE"] = "Türkçe";
$lang["LANGUAGENAMEHTML"] = "T&uuml;rk&ccedil;e";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "Kayıt";
$lang["DIFF"] = "Fark";

$lang["NOREP"] = "Bir depo tanımlanmadı";
$lang["NOPATH"] = "Patika bulunamadı";
// $lang["NOACCESS"] = "You do not have the necessary permissions to read this content";
// $lang["RESTRICTED"] = "Restricted access";
$lang["SUPPLYREP"] = "Lütfen, include/config.php dosyasında \$config->parentPath ya da \$config->addRepository değerlerini kullanarak bir depo yolu belirtin<p>Daha fazla bilgi için kurulum kılavuzuna bakın";

$lang["DIFFREVS"] = "Sürümler arası fark";
$lang["AND"] = "ve";
$lang["REV"] = "Sürüm";
$lang["LINE"] = "Satır";
$lang["LINENO"] = "Satır No.";
$lang["SHOWENTIREFILE"] = "Tüm dosyayı göster";
$lang["SHOWCOMPACT"] = "Yalnızca değişen bölümleri göster";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Önceki ile karşılaştır";
$lang["BLAME"] = "svn blame";
$lang["BLAMEFOR"] = "svn blame bilgisi alınan sürüm numarası";

$lang["REVINFO"] = "Sürüm Bilgisi";
$lang["GOYOUNGEST"] = "En güncel sürüme git";
$lang["LASTMOD"] = "Son değişiklik";
$lang["LOGMSG"] = "Kayıt mesajı";
$lang["CHANGES"] = "Değişiklikler";
$lang["SHOWCHANGED"] = "Değişen dosyaları göster";
$lang["HIDECHANGED"] = "Değişen dosyaları gizle";
$lang["NEWFILES"] = "Yeni Dosyalar";
$lang["CHANGEDFILES"] = "Değişen dosyalar";
$lang["DELETEDFILES"] = "Silinen dosyalar";
$lang["VIEWLOG"] = "Kayıt Mesajını Göster";
$lang["PATH"] = "Patika";
$lang["AUTHOR"] = "Yazar";
$lang["AGE"] = "Yaş";
$lang["CURDIR"] = "Şimdiki Dizin";
$lang["TARBALL"] = "Tar dosyası";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Önceki";
$lang["NEXT"] = "Sonraki";
$lang["SHOWALL"] = "Tümünü Göster";

$lang["BADCMD"] = "Bu komut çalıştırılırken hata oluştu";
// $lang["UNKNOWNREVISION"] = "Revision not found";

$lang["POWERED"] = "<a href=\"https://websvnphp.github.io/\">WebSVN</a> tarafından çalıştırılmaktadır";
$lang["PROJECTS"] = "Subversion Projeleri";
$lang["SERVER"] = "Subversion Sunucusu";

// $lang["FILTER"] = "Filtering Options";
// $lang["STARTLOG"] = "From rev";
// $lang["ENDLOG"] = "To rev";
// $lang["MAXLOG"] = "Max revs";
$lang["SEARCHLOG"] = "Kayıtlarda ara";
$lang["CLEARLOG"] = "Mevcut aramayı iptal et";
$lang["MORERESULTS"] = "Daha fazla eşleştirmeyi bul...";
$lang["NORESULTS"] = "Aramaya uyan kayıt mesajı yok";
$lang["NOMORERESULTS"] = "Aramaya uyan başka kayıt mesajı yok";
// $lang["NOPREVREV"] = "No previous revision";

$lang["RSSFEEDTITLE"] = "WebSVN RSS kaynağı";
$lang["FILESMODIFIED"] = "dosya değişti";
$lang["RSSFEED"] = "RSS kaynağı";

$lang["DAYLETTER"] = "g";
$lang["HOURLETTER"] = "s";
$lang["MINUTELETTER"] = "d";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Git";

$lang["PATHCOMPARISON"] = "Patika karşılaştırması";
$lang["COMPAREPATHS"] = "Patikaları karşılaştır";
$lang["COMPAREREVS"] = "Sürümleri karşışaştır";
$lang["PROPCHANGES"] = "Özellik değişiklikleri:";
$lang["CONVFROM"] = "Bu karşılaştırma patikayı dönüştürmek için gerekli olan değişikliği gösterir ";
$lang["TO"] = "TO";
$lang["REVCOMP"] = "Geriye doğru karşılaştır";
$lang["COMPPATH"] = "Patikaları karşılaştır:";
$lang["WITHPATH"] = "Patika ile:";
$lang["FILEDELETED"] = "Dosya silinmiş";
$lang["FILEADDED"] = "Yeni dosya";

$lang['SEARCH'] = "Arama";
$lang['SEARCH_PLACEHOLDER'] = "Burada ürün arayın";
$lang['NOITEMSFOUND'] = "Hiç bir öğe bulunamadı";
