<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// japanese.php
//
// Japanese(UTF-8) language strings
// Translator: BEPPU Masamichi

$lang["LANGUAGETAG"] = "ja"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Japanese";
$lang["LANGUAGENAMENATIVE"] = "日本語";
$lang["LANGUAGENAMEHTML"] = "&#26085;&#26412;&#35486;";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "ログ";
$lang["DIFF"] = "差分";

$lang["NOREP"] = "リポジトリが指定されていません";
$lang["NOPATH"] = "パスが見付かりません";
// $lang["NOACCESS"] = "You do not have the necessary permissions to view this content.";
$lang["RESTRICTED"] = "アクセスが制限されています";
$lang["SUPPLYREP"] = "ファイル include/config.php 内に <code>\$config->parentPath</code> もしくは <code>\$config->addRepository</code> を使用してリポジトリパスを設定してください。詳しくはインストールガイドを参照してください。";

$lang["DIFFREVS"] = "リビジョン間の差分";
$lang["AND"] = "と";
$lang["REV"] = "リビジョン";
$lang["LINE"] = "行";
$lang["LINENO"] = "行番号";
$lang["SHOWENTIREFILE"] = "全て表示";
$lang["SHOWCOMPACT"] = "異なる行の周辺だけ表示";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "前のリビジョンとの差分";
$lang["BLAME"] = "詳細表示";
$lang["BLAMEFOR"] = "詳細表示 対象リビジョン";

$lang["REVINFO"] = "リビジョン情報";
$lang["GOYOUNGEST"] = "最新のリビジョンへ";
$lang["LASTMOD"] = "最終更新日時";
$lang["LOGMSG"] = "ログメッセージ";
$lang["CHANGES"] = "変更";
$lang["SHOWCHANGED"] = "変更されたファイルの一覧を表示する";
$lang["HIDECHANGED"] = "変更されたファイルの一覧を表示しない";
$lang["NEWFILES"] = "追加ファイル";
$lang["CHANGEDFILES"] = "修正ファイル";
$lang["DELETEDFILES"] = "削除ファイル";
$lang["VIEWLOG"] = "ログを見る";
$lang["PATH"] = "パス";
$lang["AUTHOR"] = "修正者";
$lang["AGE"] = "無修正時間";
$lang["CURDIR"] = "カレントディレクトリ";
// $lang["TARBALL"] = "Tarball";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "前";
$lang["NEXT"] = "次";
$lang["SHOWALL"] = "全て表示";

$lang["BADCMD"] = "コマンド実行中のエラー";
$lang["UNKNOWNREVISION"] = "指定のリビジョンがありません";

// $lang["POWERED"] = "Powered by <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion リポジトリ一覧";
$lang["SERVER"] = "Subversion サーバ";

$lang["FILTER"] = "フィルタオプション";
$lang["STARTLOG"] = "開始リビジョン";
$lang["ENDLOG"] = "終了リビジョン";
$lang["MAXLOG"] = "最大リビジョン数";
$lang["SEARCHLOG"] = "ログを検索";
$lang["CLEARLOG"] = "検索条件をクリアする";
$lang["MORERESULTS"] = "検索条件を絞り込む";
$lang["NORESULTS"] = "検索条件にマッチするものはありませんでした";
$lang["NOMORERESULTS"] = "これ以上検索条件にマッチするものはありません";
$lang["NOPREVREV"] = "前のリビジョンはありません";

// $lang["RSSFEEDTITLE"] = "WebSVN RSS feed";
$lang["FILESMODIFIED"] = "ファイルが修正されました";
// $lang["RSSFEED"] = "RSS feed";

$lang["DAYLETTER"] = "日間";
$lang["HOURLETTER"] = "時間";
$lang["MINUTELETTER"] = "分";
$lang["SECONDLETTER"] = "秒";

$lang["GO"] = "GO";

$lang["PATHCOMPARISON"] = "パス比較";
$lang["COMPAREPATHS"] = "パス比較";
$lang["COMPAREREVS"] = "リビジョン比較";
$lang["PROPCHANGES"] = "プロパティ変更：";
$lang["CONVFROM"] = "この比較は次の2つのパス配下すべてのファイルの比較をします。比較対象パス：";
$lang["TO"] = "と";
$lang["REVCOMP"] = "逆比較";
$lang["COMPPATH"] = "比較元パス：";
$lang["WITHPATH"] = "比較先パス：";
$lang["FILEDELETED"] = "ファイル削除";
$lang["FILEADDED"] = "新規ファイル";

$lang['NOSEARCHTERM'] = "検索条件が指定されていません";
$lang['SEARCH'] = "検索";
$lang['SEARCH_PLACEHOLDER'] = "こちらから項目を検索";
$lang['NOITEMSFOUND'] = "項目は見つかりませんでした";
