<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// portuguese.php
//
// Portuguese language strings (UTF-8)

$lang["LANGUAGETAG"] = "pt"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Portuguese";
$lang["LANGUAGENAMENATIVE"] = "Português";
$lang["LANGUAGENAMEHTML"] = "Portugu&ecirc;s";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diferenças";

$lang["NOREP"] = "Não foi indicado um repositório";
$lang["NOPATH"] = "Caminho inválido";
$lang["NOACCESS"] = "Você não tem as permissões necessárias para ler esse diretório";
$lang["RESTRICTED"] = "Acesso restrito";
$lang["SUPPLYREP"] = "Favor de configurar um repositório em include/config.php usando \$config->parentPath ou \$config->addRepository. Veja o guia de instalação para mais detalhes.";

$lang["DIFFREVS"] = "Diferenças entre revisões";
$lang["AND"] = "e";
$lang["REV"] = "Revisão";
$lang["LINE"] = "Linha";
$lang["LINENO"] = "Linha Nº";
$lang["SHOWENTIREFILE"] = "Mostrar todo o ficheiro";
$lang["SHOWCOMPACT"] = "Mostrar apenas áreas com diferenças";
$lang["IGNOREWHITESPACE"] = "Ignorar whitespace";
$lang["REGARDWHITESPACE"] = "Considerar whitespace";

$lang["LISTING"] = "Conteúdo do diretório";
$lang["FILEDETAIL"] = "Detalhes";
$lang["VIEWAS"] = "Mostrar como";
$lang["DIFFPREV"] = "Diferenças com a anterior";
$lang["BLAME"] = "Anotações";
$lang["BLAMEFOR"] = "Anotações para revisão";

$lang["REVINFO"] = "Notas desta revisão";
$lang["GOYOUNGEST"] = "Revisão mais recente";
$lang["LASTMOD"] = "Última alteração";
$lang["LOGMSG"] = "Mensagem de log";
$lang["CHANGES"] = "Alterações";
$lang["SHOWCHANGED"] = "Mostrar ficheiros alterados";
$lang["HIDECHANGED"] = "Esconder ficheiros alterados";
$lang["NEWFILES"] = "Ficheiros novos";
$lang["CHANGEDFILES"] = "Ficheiros alterados";
$lang["DELETEDFILES"] = "Ficheiros apagados";
$lang["VIEWLOG"] = "Ver log";
$lang["PATH"] = "Caminho";
$lang["AUTHOR"] = "Autor";
$lang["AGE"] = "Idade";
$lang["CURDIR"] = "Directoria currente";
$lang["TARBALL"] = "Baixar";
$lang["DOWNLOAD"] = "Baixar";

$lang["PREV"] = "Anterior";
$lang["NEXT"] = "Seguinte";
$lang["SHOWALL"] = "Mostrar todos";

$lang["BADCMD"] = "Erro ao correr este comando";
$lang["UNKNOWNREVISION"] = "Revisão não encontrada";

// $lang["POWERED"] = "Powered by <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion Projectos";
$lang["SERVER"] = "Subversion Servidor";

$lang["FILTER"] = "Opções de filtro";
$lang["STARTLOG"] = "De revisão";
$lang["ENDLOG"] = "Até revisão";
$lang["MAXLOG"] = "Limite de entradas";
$lang["SEARCHLOG"] = "Pesquisar o log por";
$lang["CLEARLOG"] = "Limpar pesquisa";
$lang["MORERESULTS"] = "Encontrar mais...";
$lang["NORESULTS"] = "A pesquisa não devolveu nenhum log";
$lang["NOMORERESULTS"] = "Não existem mais resultados (logs) para a pesquisa";
$lang["NOPREVREV"] = "Nenhuma revisão anterior";

// $lang["RSSFEEDTITLE"] = "WebSVN RSS feed";
$lang["FILESMODIFIED"] = "ficheiro(s) modificado(s)";
// $lang["RSSFEED"] = "RSS feed";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

// $lang["GO"] = "Go";

$lang["PATHCOMPARISON"] = "Comparação de caminhos";
$lang["COMPAREPATHS"] = "Comparar caminhos";
$lang["COMPAREREVS"] = "Comparar revisões";
$lang["PROPCHANGES"] = "Modificações de propriedades:";
$lang["CONVFROM"] = "Esta comparação mostra as modificações necessárias para converter o caminho ";
$lang["TO"] = "para";
$lang["REVCOMP"] = "Comparação reversa";
$lang["COMPPATH"] = "Comparar caminho:";
$lang["WITHPATH"] = "Com caminho:";
$lang["FILEDELETED"] = "Arquivo apagado";
$lang["FILEADDED"] = "Arquivo adicionado";

$lang['SEARCH'] = "Procurar";
$lang['SEARCH_PLACEHOLDER'] = "Procure por itens aqui";
$lang['NOITEMSFOUND'] = "Nenhum item encontrado";
