<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// danish.php
//
// Danish language strings based on TortoiseSVN translation.
// by Jan Normann Nielsen, <span@dubbekarl.dk>

$lang["LANGUAGETAG"] = "da"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Danish";
$lang["LANGUAGENAMENATIVE"] = "Dansk";
$lang["LANGUAGENAMEHTML"] = "Dansk";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

// $lang["LOG"] = "Log";
$lang["DIFF"] = "Sammenlign";

$lang["NOREP"] = "Der er ikke angivet noget versionarkiv";
$lang["NOPATH"] = "Stien blev ikke fundet";
$lang["NOACCESS"] = "Du har ikke de nødvendige rettigheder til at læse denne mappe";
$lang["RESTRICTED"] = "Begrænset adgang";
$lang["SUPPLYREP"] = "Konfigurer venligst stier til versionsarkiver i include/config.php ved at bruge \$config->parentPath eller \$config->addRepository<p>. Se installationsguiden for nærmere detaljer.";

$lang["DIFFREVS"] = "Sammenlign revisionerne";
$lang["AND"] = "og";
$lang["REV"] = "Rev";
$lang["LINE"] = "Linje";
$lang["LINENO"] = "Linjenr.";
$lang["SHOWENTIREFILE"] = "Vis hele filen";
$lang["SHOWCOMPACT"] = "Vis kun områder med forskelle";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Sammenlign med forrige";
$lang["BLAME"] = "ændringsfordeling";
$lang["BLAMEFOR"] = "ændringsfordeling for revision";

$lang["REVINFO"] = "Informationer om revision";
$lang["GOYOUNGEST"] = "Gå til nyeste revision";
$lang["LASTMOD"] = "Sidste ændring";
$lang["LOGMSG"] = "Logbesked";
$lang["CHANGES"] = "ændringer";
$lang["SHOWCHANGED"] = "Vis ændrede filer";
$lang["HIDECHANGED"] = "Skjul ændrede filer";
$lang["NEWFILES"] = "Nye filer";
$lang["CHANGEDFILES"] = "ændrede filer";
$lang["DELETEDFILES"] = "Slettede filer";
$lang["VIEWLOG"] = "Vis log";
$lang["PATH"] = "Sti";
$lang["AUTHOR"] = "Forfatter";
$lang["AGE"] = "Alder";
$lang["CURDIR"] = "Nuværende mappe";
$lang["TARBALL"] = "Tar-pakke";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Forrige";
$lang["NEXT"] = "Næste";
$lang["SHOWALL"] = "Vis alle";

$lang["BADCMD"] = "Fejl ved udførelse af kommandoen";
$lang["UNKNOWNREVISION"] = "Revisionen findes ikke";

$lang["POWERED"] = "Leveret af <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion-versionsarkiver";
$lang["SERVER"] = "Subversion-server";

$lang["FILTER"] = "Filter-indstillinger";
$lang["STARTLOG"] = "Fra rev";
$lang["ENDLOG"] = "Til rev";
// $lang["MAXLOG"] = "Max revisions";
$lang["SEARCHLOG"] = "Søg efter";
$lang["CLEARLOG"] = "Ryd aktuelle filter";
$lang["MORERESULTS"] = "Vis flere resultater...";
$lang["NORESULTS"] = "Der er ingen logbeskeder, der passer på søgningen";
$lang["NOMORERESULTS"] = "Der er ikke flere logbeskeder, som svarer til søgningen";
$lang["NOPREVREV"] = "Ingen forrige revision";

$lang["RSSFEEDTITLE"] = "WebSVN RSS-feed";
$lang["FILESMODIFIED"] = "fil(er) ændret";
$lang["RSSFEED"] = "RSS-feed";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "t";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Gå til";

$lang["PATHCOMPARISON"] = "Sammenligning af stier";
$lang["COMPAREPATHS"] = "Sammenlign stier";
$lang["COMPAREREVS"] = "Sammenlign revisioner";
$lang["PROPCHANGES"] = "ændringer i egenskaber:";
$lang["CONVFROM"] = "Denne sammenligning viser de ændringer, der skal til for at konvertere stien ";
$lang["TO"] = "til";
$lang["REVCOMP"] = "Omvendt sammenligning";
$lang["COMPPATH"] = "Sammenlign sti:";
$lang["WITHPATH"] = "med sti:";
$lang["FILEDELETED"] = "Fil slettet";
$lang["FILEADDED"] = "Ny fil";

$lang['SEARCH'] = "Søg";
$lang['SEARCH_PLACEHOLDER'] = "Søg efter emner her";
$lang['NOITEMSFOUND'] = "Ingen varer fundet";
