<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2005 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// finnish.php
//
// Finnish language strings
// Matti Pöllä <mpo@iki.fi>

$lang["LANGUAGETAG"] = "fi"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Finnish";
$lang["LANGUAGENAMENATIVE"] = "Suomi";
$lang["LANGUAGENAMEHTML"] = "Suomi";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "Loki";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "Tietokantaa ei ole valittu";
$lang["NOPATH"] = "Polkua ei löydy";
// $lang["NOACCESS"] = "You do not have the necessary permissions to read this content";
// $lang["RESTRICTED"] = "Restricted access";
$lang["SUPPLYREP"] = "Aseta tietokannan polku tiedostossa include/config.php käyttäen muuttujaa \$config->parentPath tai \$config->addRepository<p>Katso asennusoppaasta yksityiskohtaiset ohjeet";

$lang["DIFFREVS"] = "Versioiden väliset muutokset";
$lang["AND"] = "ja";
$lang["REV"] = "Versio";
$lang["LINE"] = "Rivi";
$lang["LINENO"] = "Rivi Nro.";
$lang["SHOWENTIREFILE"] = "Näytä koko tiedosto";
$lang["SHOWCOMPACT"] = "Näytä vain muutoksia sisältävät alueet";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Vertaa Edelliseen";
$lang["BLAME"] = "Blame";
$lang["BLAMEFOR"] = "Blame-tiedot versiolle";

$lang["REVINFO"] = "Version Tiedot";
$lang["GOYOUNGEST"] = "Siirry uusimpaan versioon";
$lang["LASTMOD"] = "Viimeinen muokkaus";
$lang["LOGMSG"] = "Lokiviesti";
$lang["CHANGES"] = "Muutokset";
$lang["SHOWCHANGED"] = "Näytä muutoksia siältävät tiedostot";
$lang["HIDECHANGED"] = "Piilota muutoksia sisältävät tiedostot";
$lang["NEWFILES"] = "Uudet tiedostot";
$lang["CHANGEDFILES"] = "Muokatut tiedostot";
$lang["DELETEDFILES"] = "Poistetut tiedostot";
$lang["VIEWLOG"] = "Näytä Loki";
$lang["PATH"] = "Polku";
$lang["AUTHOR"] = "Tekijä";
$lang["AGE"] = "Ikä";
$lang["CURDIR"] = "Tämä Hakemisto";
$lang["TARBALL"] = "Tar-tiedosto";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Edellinen";
$lang["NEXT"] = "Seuraava";
$lang["SHOWALL"] = "Näytä Kaikki";

$lang["BADCMD"] = "Virhe komennon suorittamisessa";
// $lang["UNKNOWNREVISION"] = "Revision not found";

$lang["POWERED"] = "Moottorina <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion Projektit";
$lang["SERVER"] = "Subversion-palvelin";

// $lang["FILTER"] = "Filtering Options";
// $lang["STARTLOG"] = "From rev";
// $lang["ENDLOG"] = "To rev";
// $lang["MAXLOG"] = "Max revs";
$lang["SEARCHLOG"] = "Etsi lokista";
$lang["CLEARLOG"] = "Tyhjennä tämä haku";
$lang["MORERESULTS"] = "Hae lisää osumia...";
$lang["NORESULTS"] = "Mikään loki ei vastaa kyselyä";
$lang["NOMORERESULTS"] = "Kyselyä vastaavia lokeja ei ole enemmän";
// $lang["NOPREVREV"] = "No previous revision";

$lang["RSSFEEDTITLE"] = "WebSVN RSS-syöte";
$lang["FILESMODIFIED"] = "tiedosto(a) muokattu";
$lang["RSSFEED"] = "RSS-syöte";

$lang["DAYLETTER"] = "p";
$lang["HOURLETTER"] = "t";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Siirry";

$lang["PATHCOMPARISON"] = "Polkujen Vertailu";
$lang["COMPAREPATHS"] = "Vertaa Polkuja";
$lang["COMPAREREVS"] = "Vertaile Versioita";
$lang["PROPCHANGES"] = "Ominaisuuksien muutokset:";
$lang["CONVFROM"] = "Tämä vertailu näyttää polun muuntamiseen tarvittavat muutokset ";
// $lang["TO"] = "to";
$lang["REVCOMP"] = "Vertailu käänteiseen suuntaan";
$lang["COMPPATH"] = "Vertaile Polkua:";
$lang["WITHPATH"] = "Vertailtava Polku:";
$lang["FILEDELETED"] = "Tiedosto poistettu";
$lang["FILEADDED"] = "Uusi tiedosto";

$lang['SEARCH'] = "Hae";
$lang['SEARCH_PLACEHOLDER'] = "Hae kohteita täältä";
$lang['NOITEMSFOUND'] = "Kohteita ei löytynyt";
