<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// chinese-traditional.php
//
// Traditional Chinese language strings
//
// Author: Yuan-Chung Hsiao <ychsiao@ychsiao.idv.tw>

$lang["LANGUAGETAG"] = "zh-TW"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Traditional Chinese";
$lang["LANGUAGENAMENATIVE"] = "中文";
$lang["LANGUAGENAMEHTML"] = "&#20013;&#25991;";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "歷史記錄";
$lang["DIFF"] = "比對";

$lang["NOREP"] = "沒有檔案庫";
$lang["NOPATH"] = "找不到路徑";
// $lang["NOACCESS"] = "You do not have the necessary permissions to read this content";
// $lang["RESTRICTED"] = "Restricted access";
$lang["SUPPLYREP"] = "請在include/config.php中設定檔案庫位置為 \$config->parentPath 或 \$config->addRepository<p>更詳細的內容請見安裝手冊";

$lang["DIFFREVS"] = "不同版本間的差異";
$lang["AND"] = "與";
$lang["REV"] = "修訂版號";
$lang["LINE"] = "行";
$lang["LINENO"] = "行";
$lang["SHOWALL"] = "顯示完整的檔案";
$lang["SHOWCOMPACT"] = "只顯示不同處";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "與前一版次比較";
$lang["BLAME"] = "譴責";
$lang["BLAMEFOR"] = "版本譴責資訊";

$lang["REVINFO"] = "修訂版次資訊";
$lang["GOYOUNGEST"] = "到最新的修訂";
$lang["LASTMOD"] = "最後更動";
$lang["LOGMSG"] = "訊息記錄";
$lang["CHANGES"] = "改變";
$lang["SHOWCHANGED"] = "顯示已變動檔案";
$lang["HIDECHANGED"] = "隱藏已變動檔案";
$lang["NEWFILES"] = "新檔案";
$lang["CHANGEDFILES"] = "已變動檔案";
$lang["DELETEDFILES"] = "已刪除檔案";
$lang["VIEWLOG"] = "看歷史記錄";
$lang["PATH"] = "路徑";
$lang["AUTHOR"] = "作者";
$lang["AGE"] = "更動時間";
$lang["CURDIR"] = "目前目錄";
$lang["TARBALL"] = "Tarball 格式";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "上一筆";
$lang["NEXT"] = "下一筆";
$lang["SHOWALL"] = "顯示全部";

$lang["BADCMD"] = "執行錯誤";
// $lang["UNKNOWNREVISION"] = "Revision not found";

$lang["POWERED"] = "採用 <a href=\"https://websvnphp.github.io/\">WebSVN</a>架設";
$lang["PROJECTS"] = "Subversion 專案";
$lang["SERVER"] = "Subversion Server";

// $lang["FILTER"] = "Filtering Options";
// $lang["STARTLOG"] = "From rev";
// $lang["ENDLOG"] = "To rev";
// $lang["MAXLOG"] = "Max revs";
$lang["SEARCHLOG"] = "搜尋記錄內容";
$lang["CLEARLOG"] = "清除目前搜尋";
$lang["MORERESULTS"] = "找到更多的符合的...";
$lang["NORESULTS"] = "查詢結果並沒有符合的紀錄";
$lang["NOMORERESULTS"] = "沒有更多紀錄符合你的查詢";

$lang["RSSFEEDTITLE"] = "WebSVN RSS feed";
$lang["FILESMODIFIED"] = "個檔案變動";
$lang["RSSFEED"] = "RSS feed";

$lang["DAYLETTER"] = "日前";
$lang["HOURLETTER"] = "小時前";
$lang["MINUTELETTER"] = "分鐘前";
$lang["SECONDLETTER"] = "秒前";

$lang["GO"] = "到";

// $lang["PATHCOMPARISON"] = "Path Comparison";
$lang["COMPAREPATHS"] = "比對路徑";
$lang["COMPAREREVS"] = "比對修訂版";
$lang["PROPCHANGES"] = "改變屬性:";
$lang["CONVFROM"] = "這個比對顯示必需改變轉換路徑";
$lang["TO"] = "到";
$lang["REVCOMP"] = "顛倒比對";
// $lang["COMPPATH"] = "Compare Path:";
// $lang["WITHPATH"] = "With Path:";
// $lang["FILEDELETED"] = "File deleted";
// $lang["FILEADDED"] = "New file";

$lang['SEARCH'] = "搜索";
$lang['SEARCH_PLACEHOLDER'] = "在這裡搜索項目";
$lang['NOITEMSFOUND'] = "未找到任何項目";
