<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// dutch.php
//
// Dutch language strings
//
// By David Gartner david A.T net2ftp D-O-T com
// Comments welcome.

$lang["LANGUAGETAG"] = "nl"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Dutch";
$lang["LANGUAGENAMENATIVE"] = "Nederlands";
$lang["LANGUAGENAMEHTML"] = "Nederlands";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "Geen repository ingegeven";
$lang["NOPATH"] = "Pad niet gevonden";
// $lang["NOACCESS"] = "You do not have the necessary permissions to read this content";
// $lang["RESTRICTED"] = "Restricted access";
$lang["SUPPLYREP"] = "Gelieve een repositorypad aan te maken in include/config.php met behulp van \$config->parentPath of \$config->addRepository<p>Zie de installatiegids voor meer details";

$lang["DIFFREVS"] = "Verschil tussen de revisies";
$lang["AND"] = "en";
$lang["REV"] = "Rev";
$lang["LINE"] = "Regel";
$lang["LINENO"] = "Regelnr.";
$lang["SHOWENTIREFILE"] = "Toon volledig bestand";
$lang["SHOWCOMPACT"] = "Toon enkel de delen met verschillen";
$lang["IGNOREWHITESPACE"] = "Negeer witruimtes";
$lang["REGARDWHITESPACE"] = "Toon witruimtes";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Vergelijk met vorige";
$lang["BLAME"] = "Blame";
$lang["BLAMEFOR"] = "Blame-informatie voor revisie";

$lang["REVINFO"] = "Revisie-informatie";
$lang["GOYOUNGEST"] = "Ga naar de meest recente revisie";
$lang["LASTMOD"] = "Laatste wijziging";
$lang["LOGMSG"] = "Logbericht";
$lang["CHANGES"] = "Wijzigingen";
$lang["SHOWCHANGED"] = "Toon gewijzigde bestanden";
$lang["HIDECHANGED"] = "Verberg gewijzigde bestanden";
$lang["NEWFILES"] = "Nieuwe bestanden";
$lang["CHANGEDFILES"] = "Gewijzigde bestanden";
$lang["DELETEDFILES"] = "Gewiste files";
$lang["VIEWLOG"] = "Toon Log";
$lang["PATH"] = "Pad";
$lang["AUTHOR"] = "Auteur";
$lang["AGE"] = "Leeftijd";
$lang["CURDIR"] = "Huidige map";
// $lang["TARBALL"] = "Tarball";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Vorige";
$lang["NEXT"] = "Volgende";
$lang["SHOWALL"] = "Toon alles";

$lang["BADCMD"] = "Een fout is opgetreden tijdens het uitvoeren van dit commando";
// $lang["UNKNOWNREVISION"] = "Revision not found";

$lang["POWERED"] = "Aangedreven door <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion-projecten";
$lang["SERVER"] = "Subversion-server";

// $lang["FILTER"] = "Filtering Options";
// $lang["STARTLOG"] = "From rev";
// $lang["ENDLOG"] = "To rev";
// $lang["MAXLOG"] = "Max revs";
$lang["SEARCHLOG"] = "Doorzoek de logs";
$lang["CLEARLOG"] = "Wis deze zoekopdracht";
$lang["MORERESULTS"] = "Vind meer resultaten...";
$lang["NORESULTS"] = "Er zijn geen logs die aan de zoekcriteria voldoen";
$lang["NOMORERESULTS"] = "Er zijn geen logs meer die aan de zoekcriteria voldoen";
// $lang["NOPREVREV"] = "No previous revision";

// $lang["RSSFEEDTITLE"] = "WebSVN RSS feed";
$lang["FILESMODIFIED"] = "bestand(en) gewijzigd";
// $lang["RSSFEED"] = "RSS feed";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "u";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Ga";

$lang["PATHCOMPARISON"] = "Padvergelijking";
$lang["COMPAREPATHS"] = "Vergelijk paden";
$lang["COMPAREREVS"] = "Vergelijk revisies";
$lang["PROPCHANGES"] = "Eigenschapswijzigingen:";
$lang["CONVFROM"] = "Deze vergelijking geeft de veranderingen weer die nodig zijn om het pad te converteren ";
$lang["TO"] = "TO";
$lang["REVCOMP"] = "Omgekeerde vergelijking";
$lang["COMPPATH"] = "Vergelijk pad:";
$lang["WITHPATH"] = "Met pad:";
$lang["FILEDELETED"] = "Bestand gewist";
$lang["FILEADDED"] = "Nieuw bestand";

$lang['SEARCH'] = "Zoeken";
$lang['SEARCH_PLACEHOLDER'] = "Zoek hier naar items";
$lang['NOITEMSFOUND'] = "Geen items gevonden";
