<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// marathi.php
//
// Marathi language strings
// मराठी भाषेतील शब्द
// Translator: Aniruddha Thombre <imagineers7@yahoo.com>
// अनुवादक: अनिरुद्ध ठोंबरे

$lang["LANGUAGETAG"] = "mr"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Marathi";
$lang["LANGUAGENAMENATIVE"] = "मराठी";
$lang["LANGUAGENAMEHTML"] = "&#2350;&#2352;&#2366;&#2336;&#2368;";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "शेरा";
$lang["DIFF"] = "फरक";

$lang["NOREP"] = "आवृत्तिकोष दिला नाही";
$lang["NOPATH"] = "मार्ग सापडला नाही";
$lang["NOACCESS"] = "तुमच्याकडे ही माहिती पाहण्याचे पुरेसे अधिकार नाहीत";
$lang["RESTRICTED"] = "मर्यादित अधिकार";
$lang["SUPPLYREP"] = "कृपया, include/config.php या खतावणी मध्ये \$config->parentPath किंवा \$config->addRepository  वापरुन आवृत्तिकोषाचा मार्ग संस्थापित करा.<p>अधिक माहितीसाठी प्रस्थापना पुस्तिका पहा";

$lang["DIFFREVS"] = "आवृत्त्यांमधील बदल";
$lang["AND"] = "आणि";
$lang["REV"] = "आवृत्ती";
$lang["LINE"] = "ओळ";
$lang["LINENO"] = "ओळ क्र.";
$lang["SHOWENTIREFILE"] = "संपूर्ण खतावणी पहा";
$lang["SHOWCOMPACT"] = "फक्त बदलेले भाग पहा";
$lang["IGNOREWHITESPACE"] = "रिकाम्या जागा दुर्लक्षित करा";
$lang["REGARDWHITESPACE"] = "रिकाम्या जागाही पहा";

$lang["LISTING"] = "यादीची सूची";
$lang["FILEDETAIL"] = "अधिक माहिती";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "पूर्वीच्या आवृत्तीशी तुलना करा";
$lang["BLAME"] = "जबाबदार";
$lang["BLAMEFOR"] = "आवृत्तीसन्दर्भात  जबाबदारीची माहिती";

$lang["REVINFO"] = "आवृत्तीची माहिती";
$lang["GOYOUNGEST"] = "सर्वात नव्या  आवृत्तीकडे चला";
$lang["LASTMOD"] = "शेवटचा बदल";
$lang["LOGMSG"] = "शेरा";
$lang["CHANGES"] = "बदल";
$lang["SHOWCHANGED"] = "बदलेल्या खतावण्या पहा";
$lang["HIDECHANGED"] = "बदलेल्या खतावण्या लपवा";
$lang["NEWFILES"] = "नवीन खतावण्या";
$lang["CHANGEDFILES"] = "बदलेल्या खतावण्या";
$lang["DELETEDFILES"] = "काढलेल्या खतावण्या";
$lang["VIEWLOG"] = "नोंदी पहा";
$lang["PATH"] = "मार्ग";
$lang["AUTHOR"] = "लेखक";
$lang["AGE"] = "वय";
$lang["CURDIR"] = "सद्यसुचि";
//$lang["TARBALL"] = "Tarball";
//$lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "मागे";
$lang["NEXT"] = "पुढे";
$lang["SHOWALL"] = "सर्व पहा";

$lang["BADCMD"] = "हा आदेश चालू शकला नाही";
$lang["UNKNOWNREVISION"] = "आवृत्ती सापडली नाही";

$lang["POWERED"] = "<a href=\"https://websvnphp.github.io/\">WebSVN</a> ने संचालीत";
$lang["PROJECTS"] = "Subversion आवृत्तीकोष";
$lang["SERVER"] = "Subversion संगणक";

$lang["FILTER"] = "गाळणीचे निकष";
$lang["STARTLOG"] = "आवृत्ती पासून";
$lang["ENDLOG"] = "आवृत्ती पर्यंत";
$lang["MAXLOG"] = "अधिकतम आवृत्ती";
$lang["SEARCHLOG"] = "साठी शोधा";
$lang["CLEARLOG"] = "आत्ताचे निकष काढ़ा";
$lang["MORERESULTS"] = "आणखी नोंदी पहा...";
$lang["NORESULTS"] = "अश्या नोंदी उपलब्ध नाहित";
$lang["NOMORERESULTS"] = "तुमच्या शोधण्यात आणखी नोंदी नाहीत";
$lang["NOPREVREV"] = "यापुर्वी ची आवृत्ती नाही";

$lang["RSSFEEDTITLE"] = "WebSVN ख.सा.स.पोस";
$lang["FILESMODIFIED"] = "बदललेल्या खतावण्या";
$lang["RSSFEED"] = " ख.सा.स.पोस";

$lang["DAYLETTER"] = "दि.";
$lang["HOURLETTER"] = "ता.";
$lang["MINUTELETTER"] = "मी.";
$lang["SECONDLETTER"] = "प.";

$lang["GO"] = "जा";

$lang["PATHCOMPARISON"] = "मार्ग तुलना";
$lang["COMPAREPATHS"] = "मार्ग तुलना";
$lang["COMPAREREVS"] = "आवृत्त्यातील तुलना";
$lang["PROPCHANGES"] = "गुण बदल:";
$lang["CONVFROM"] = "ही तुलना मार्ग बदलण्यासाठी आवश्यक असलेले फरक दाखविते";
$lang["TO"] = "कडे";
$lang["REVCOMP"] = "उलट तुलना";
$lang["COMPPATH"] = "मार्ग तुलना:";
$lang["WITHPATH"] = "या मार्गाशी:";
$lang["FILEDELETED"] = "खतावणी काढली";
$lang["FILEADDED"] = "नवीन  खतावणी";

$lang['SEARCH'] = "शोधा";
$lang['SEARCH_PLACEHOLDER'] = "येथे आयटम शोधा";
$lang['NOITEMSFOUND'] = "कोणतेही आयटम सापडले नाहीत";
