<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// catalan.php
//
// Catalan language strings

$lang["LANGUAGETAG"] = "ca"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Catalan";
$lang["LANGUAGENAMENATIVE"] = "Català-Valencià";
$lang["LANGUAGENAMEHTML"] = "Catal&agrave;-Valenci&agrave;";

$lang['BREADCRUMB_REPO_ROOT'] = '(root)';

$lang["LOG"] = "Registre";
$lang["DIFF"] = "Diferència";

$lang["NOREP"] = "No s'ha proporcionat cap dipòsit";
$lang["NOPATH"] = "No s'ha trobat cap camí";
$lang["NOACCESS"] = "No teniu els permisos necessaris per a llegir aquest directori";
$lang["RESTRICTED"] = "Accés restringit";
$lang["SUPPLYREP"] = "Definiu un camí per al dipòsit a include/config.php utilitzant \$config->parentPath o \$config->addRepository<p>Vegeu la guia d'instal·lació per a més detalls";

$lang["DIFFREVS"] = "Diferències entre revisions";
$lang["AND"] = "i";
$lang["REV"] = "Revisió";
$lang["LINE"] = "Línia";
$lang["LINENO"] = "Línia núm.";
$lang["SHOWENTIREFILE"] = "Mostra el fitxer sencer";
$lang["SHOWCOMPACT"] = "Mostra només les àrees amb diferències";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
// $lang["VIEWAS"] = "View as";
$lang["DIFFPREV"] = "Compara amb l'anterior";
$lang["BLAME"] = "Culpa";
$lang["BLAMEFOR"] = "Informació de culpa per a la revisió";

$lang["REVINFO"] = "Informació de la revisió";
$lang["GOYOUNGEST"] = "Vés a la revisió més recent";
$lang["LASTMOD"] = "Darrera modificació";
$lang["LOGMSG"] = "Missatge de registre";
$lang["CHANGES"] = "Canvis";
$lang["SHOWCHANGED"] = "Mostra els fitxers canviats";
$lang["HIDECHANGED"] = "Amaga els fitxers canviats";
$lang["NEWFILES"] = "Nous fitxers";
$lang["CHANGEDFILES"] = "Fitxers modificats";
$lang["DELETEDFILES"] = "Fitxers suprimits";
$lang["VIEWLOG"] = "Visualitza el registre";
$lang["PATH"] = "Camí";
$lang["AUTHOR"] = "Autor";
$lang["AGE"] = "Edat";
$lang["CURDIR"] = "Directori actual";
$lang["TARBALL"] = "Arxiu tar";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "Anterior";
$lang["NEXT"] = "Següent";
$lang["SHOWALL"] = "Mostra-ho tot";

$lang["BADCMD"] = "S'ha produït un error en exectuar aquesta ordre";
$lang["UNKNOWNREVISION"] = "No s'ha trobat la revisió";

$lang["POWERED"] = "Funciona amb <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Dipòsits de Subversion";
$lang["SERVER"] = "Servidor de Subversion";

$lang["FILTER"] = "Opcions de filtratge";
$lang["STARTLOG"] = "Des de la revisió";
$lang["ENDLOG"] = "A la revisió";
$lang["MAXLOG"] = "Màximes revisions";
$lang["SEARCHLOG"] = "Cerca";
$lang["CLEARLOG"] = "Neteja el filtre actual";
$lang["MORERESULTS"] = "Cerca més coincidències...";
$lang["NORESULTS"] = "No hi ha cap registre que coincideixi amb la vostra cerca";
$lang["NOMORERESULTS"] = "No hi ha més registres que coincideixin amb la vostra cerca";
$lang["NOPREVREV"] = "No hi ha cap revisió anterior.";

$lang["RSSFEEDTITLE"] = "Canal RSS del WebSVN";
$lang["FILESMODIFIED"] = "fitxer(s) modificat(s)";
$lang["RSSFEED"] = "Canal RSS";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Vés-hi";

$lang["PATHCOMPARISON"] = "Comparació de camins";
$lang["COMPAREPATHS"] = "Compara els camins";
$lang["COMPAREREVS"] = "Compara les revisions";
$lang["PROPCHANGES"] = "Canvis de propietat:";
$lang["CONVFROM"] = "Aquesta comparació mostra els canvis necessaris per a convertir el camí ";
$lang["TO"] = "a";
$lang["REVCOMP"] = "Comparació inversa";
$lang["COMPPATH"] = "Camí de comparació:";
$lang["WITHPATH"] = "Amb el camí:";
$lang["FILEDELETED"] = "Fitxer suprimit";
$lang["FILEADDED"] = "Nou fitxer";

$lang['SEARCH'] = "Cerca";
$lang['SEARCH_PLACEHOLDER'] = "Cerqueu articles aquí";
$lang['NOITEMSFOUND'] = "No s'ha trobat cap element";
